@@ -7,10 +7,10 @@ OC.L10N.register(
     "Saved" : "Sparad",
     "Shared secret" : "Delad hemlighet",
     "TURN server shared secret" : "TURN server delade hemlighet",
-    "TURN server protocols" : "TURN server protokoll",
     "UDP and TCP" : "UDP och TCP",
     "UDP only" : "endast UDP",
     "TCP only" : "endast TCP",
+    "TURN server protocols" : "TURN server protokoll",
     "New public conversation" : "Ny publik konversation",
     "New group conversation" : "Ny gruppkonversation",
     "{name} (public)" : "{name} (publik)",
@@ -24,7 +24,7 @@ OC.L10N.register(
     "An error occurred while starting screensharing." : "Ett fel uppstod vid skärmdelning.",
     "Participants" : "Deltagare",
     "Chat" : "Chat",
-    "Talk" : "Prata",
+    "Talk" : "Talk",
     "Waiting for {participantName} to join the call …" : "Väntar på att {participantName} ansluter sig till samtalet ...",
     "Waiting for others to join the call …" : "Väntar på andra ansluter sig till samtalet ...",
     "Exit fullscreen (f)" : "Avsluta fullskärmsläge (f)",
@@ -71,11 +71,13 @@ OC.L10N.register(
     "No messages yet, start the conversation!" : "Inga meddelanden än, starta konversationen!",
     "New message …" : "Nytt meddelande",
     "Send" : "Skicka",
+    "Share" : "Dela",
     "Guest" : "Gäst",
     "[Unknown user name]" : "[Okänt användarnam]",
     "Today" : "Idag",
     "Yesterday" : "Igår",
     "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
+    "The message you are trying to send is too long" : "Meddelandet du försöker skicka är för långt",
     "Error occurred while sending message" : "Fel inträffade när meddelande sändes",
     "File to share" : "Fil att dela",
     "Error while sharing" : "Fel vid delning",
@@ -84,10 +86,16 @@ OC.L10N.register(
     "Demote from moderator" : "Degradera från moderator",
     "Promote to moderator" : "Befordra till moderator",
     "Remove participant" : "Ta bort deltagare",
+    "Error while promoting user to moderator" : "Kunde inte göra användaren till moderator",
+    "Error while demoting moderator" : "Kunde inte ta bort moderator",
+    "Error while removing user from room" : "Kunde inte ta bort användaren från rummet",
     "Add participant …" : "Lägg till deltagare",
     "Favorited" : "Favorit",
     "Remove from favorites" : "Ta bort från favoriter",
     "Add to favorites" : "Lägg till som favorit",
+    "Always notify" : "Meddela alltid",
+    "Notify on @-mention" : "Meddela på @-mention",
+    "Never notify" : "Meddela aldrig",
     "Leave conversation" : "Lämna konversationen",
     "Delete conversation" : "Radera konversationen",
     "No other people in this call" : "Inga andra personer i detta samtal",
@@ -151,8 +159,6 @@ OC.L10N.register(
     "{actor} demoted {user} from moderator" : "{actor} tog bort {user} som moderator",
     "You demoted {user} from moderator" : "Du tog bort {user} som moderator",
     "{actor} demoted you from moderator" : "{actor} tog bort dig som moderator",
-    "{actor} shared {file}" : "{actor} delade {file}",
-    "You shared {file}" : "Du delade {file}",
     "{actor} shared a file which is no longer available" : "{actor} delade en fil som inte längre är tillgänglig",
     "You shared a file which is no longer available" : "Du delade en fil som inte längre är tillgänglig",
     "%s (guest)" : "%s (gäst)",
@@ -161,22 +167,28 @@ OC.L10N.register(
     "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Samtal med {user1}, {user2}, {user3} och {user4} (Varade {duration})",
     "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Samtal med {user1}, {user2}, {user3}, {user4} och {user5} (Varade {duration})",
     "Talk to %s" : "Prata med %s",
-    "Password request by %s" : "Lösenordet efterfrågas av %s",
     "_%n other guest_::_%n other guests_" : ["%n annan gäst","%n andra gäster"],
     ", " : ",",
+    "%s invited you to a conversation." : "%s bjöd in dig till en konversation.",
+    "You were invited to a conversation." : "Du blev inbjuden till en konversation.",
+    "Conversation invitation" : "Inbjudan till konversation",
+    "Click the button below to join." : "Klicka på knappen nedan för att gå med.",
+    "Join »%s«" : "Anslut »%s«",
+    "Join now" : "Anslut nu",
     "{user} sent you a private message" : "{user} skickade dig ett privat meddelande",
-    "%s mentioned you in a private conversation" : "%s nämnde dig i en privat konversation",
+    "{user} sent a message in conversation {call}" : "{user} skickade ett meddelande i konversation {call}",
+    "{user} sent a message in a conversation" : "{user} skickade ett meddelande i en konversation",
+    "A deleted user sent a message in conversation {call}" : "En raderad användare skickade ett meddelande i konversation {call}",
+    "A deleted user sent a message in a conversation" : "En raderad användare skickade ett meddelande i en konversation",
+    "A guest sent a message in conversation {call}" : "En gäst skickade ett meddelande i konversation {call}",
+    "A guest sent a message in a conversation" : "En gäst skickade ett meddelande i en konversation",
     "{user} mentioned you in a private conversation" : "{user} nämnde dig i en privat konversation",
-    "%s mentioned you in a group conversation: %s" : "%s nämnde dig i en gruppkonversation: %s",
-    "{user} mentioned you in a group conversation: {call}" : "{user} nämnde dig i en gruppkonversation: {call}",
-    "%s mentioned you in a group conversation" : "%s nämnde dig i en gruppkonversation",
-    "{user} mentioned you in a group conversation" : "{user} nämnde dig i en gruppkonversation",
-    "You were mentioned in a group conversation by a deleted user: %s" : "Du nämndes i en gruppkonversation av en raderad användare: %s",
-    "You were mentioned in a group conversation by a deleted user: {call}" : "Du nämndes i en gruppkonversation av en raderad användare: {call}",
-    "You were mentioned in a group conversation by a deleted user" : "Du nämndes i en gruppkonversation av en raderad användare",
-    "A guest mentioned you in a group conversation: %s" : "En gäst nämnde dig i en gruppkonversation: %s",
-    "A guest mentioned you in a group conversation: {call}" : "En gäst nämnde dig i en gruppkonversation: {call}",
-    "A guest mentioned you in a group conversation" : "En gäst nämnde dig i en gruppkonversation",
+    "{user} mentioned you in conversation {call}" : "{user} nämnde dig i konversation {call}",
+    "{user} mentioned you in a conversation" : "{user} nämnde dig i en konversation",
+    "A deleted user mentioned you in conversation {call}" : "En raderad användare nämnde dig i konversation {call}",
+    "A deleted user mentioned you in a conversation" : "En raderad användare nämnde dig i en konversation",
+    "A guest mentioned you in conversation {call}" : "En gäst nämnde dig i konversation {call}",
+    "A guest mentioned you in a conversation" : "En gäst nämnde dig i en konversation",
     "%s invited you to a private conversation" : "%s bjöd in dig till en privat konversation",
     "{user} invited you to a private conversation" : "{user} bjöd in dig till en privat konversation",
     "%s invited you to a group conversation: %s" : "%s bjöd in dig till en gruppkonversation: %s",
@@ -186,19 +198,22 @@ OC.L10N.register(
     "{user} wants to talk with you" : "{user} vill prata med dig",
     "A group call has started in {call}" : "Ett gruppsamtal har startats i {call}",
     "A group call has started" : "Ett gruppsamtal har startats",
-    "{email} requested the password to access a share" : "{email} begärde lösenordet för att komma åt en delning",
     "Invalid date, date format must be YYYY-MM-DD" : "Felaktigt datum, datumformat måste vara ÅÅÅÅ-MM-DD",
     "Conversation not found" : "Konversationen hittades inte",
     "Path is already shared with this room" : "Sökvägen är redan delad med detta rum",
+    "Video & audio-conferencing using WebRTC" : "Video- och ljudkonferens med WebRTC",
     "This call is password-protected" : "Detta samtal är lösenordsskyddat",
     "The password is wrong. Try again." : "Lösenordet är fel. Försök igen.",
     "Signaling server" : "Signalerar server",
+    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "En extern signalserver kan eventuellt användas för större installationer. Lämna tomt för att använda den interna signalservern.",
     "STUN servers" : "STUN-servrar",
     "A STUN server is used to determine the public IP address of participants behind a router." : "En STUN-server används för att bestämma den offentliga IP-adressen av deltagare bakom en router.",
     "TURN server" : "TURN server",
     "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN-servern används för att tunnla trafiken för användare som sitter bakom en brandvägg.",
     "%s Talk on your mobile devices" : "%s Talk på dina mobila enheter",
     "Join conversations at any time, any where, on any device." : "Anslut dig till konversationer när som helst, var som helst och på valfri enhet.",
+    "Android app" : "Android-app",
+    "iOS app" : " iOS-app",
     "Video calls" : "Videosamtal",
     "(group)" : " (grupp)",
     "New public call" : "Nytt offentligt samtal",
@@ -233,6 +248,19 @@ OC.L10N.register(
     "The STUN server is used to determine the public IP address of participants behind a router." : "STUN-servern används för att bestämma den publika IP-adressen av deltagare bakom en router.",
     "… %s" : "… %s",
     "%s …" : "%s …",
-    "… %s …" : "… %s …"
+    "… %s …" : "… %s …",
+    "%s mentioned you in a private conversation" : "%s nämnde dig i en privat konversation",
+    "%s mentioned you in a group conversation: %s" : "%s nämnde dig i en gruppkonversation: %s",
+    "{user} mentioned you in a group conversation: {call}" : "{user} nämnde dig i en gruppkonversation: {call}",
+    "%s mentioned you in a group conversation" : "%s nämnde dig i en gruppkonversation",
+    "{user} mentioned you in a group conversation" : "{user} nämnde dig i en gruppkonversation",
+    "You were mentioned in a group conversation by a deleted user: %s" : "Du nämndes i en gruppkonversation av en raderad användare: %s",
+    "You were mentioned in a group conversation by a deleted user: {call}" : "Du nämndes i en gruppkonversation av en raderad användare: {call}",
+    "You were mentioned in a group conversation by a deleted user" : "Du nämndes i en gruppkonversation av en raderad användare",
+    "A guest mentioned you in a group conversation: %s" : "En gäst nämnde dig i en gruppkonversation: %s",
+    "A guest mentioned you in a group conversation: {call}" : "En gäst nämnde dig i en gruppkonversation: {call}",
+    "A guest mentioned you in a group conversation" : "En gäst nämnde dig i en gruppkonversation",
+    "Password request by %s" : "Lösenordet efterfrågas av %s",
+    "{email} requested the password to access a share" : "{email} begärde lösenordet för att komma åt en delning"
 },
 "nplurals=2; plural=(n != 1);");
